@@ -4,12 +4,7 @@ from ioc_finder import find_iocs
 
 def get(content):
 
-    iocs = find_iocs(content)
-
-
-    for key, value in iocs.items():
-        print(key, value)
-    
+    iocs = find_iocs(content)    
 
     records = []
     
